@@ -28,7 +28,7 @@ checker = renormalizing.RENormalizing([
     (re.compile('b(".*?")'),
      r"\1"),
     # Python 3 changed the set representation.
-    (re.compile("set\(\[(.*)\]\)"),
+    (re.compile(r"set\(\[(.*)\]\)"),
      r"{\1}"),
     # Python 3 renames builtins.
     (re.compile("__builtin__"),
@@ -36,7 +36,8 @@ checker = renormalizing.RENormalizing([
     # Python 3 adds module name to exceptions.
     (re.compile("zope.schema.interfaces.SchemaNotProvided"),
      r"SchemaNotProvided"),
-    ])
+])
+
 
 class VerifyResults(object):
     """Mix-in for test classes with helpers for checking string data."""
@@ -46,23 +47,10 @@ class VerifyResults(object):
         for check in check_list:
             pos = result.find(check, start)
             self.assertTrue(pos >= 0,
-                         "%r not found in %r" % (check, result[start:]))
+                            "%r not found in %r" % (check, result[start:]))
             if inorder:
                 start = pos + len(check)
 
-    def verifyResultMissing(self, result, check_list):
-        for check in check_list:
-            self.assertTrue(result.find(check) < 0,
-                         "%r unexpectedly found in %r" % (check, result))
 
 def patternExists(pattern, source, flags=0):
     return re.search(pattern, source, flags) is not None
-
-def validationErrorExists(field, error_msg, source):
-    regex = re.compile(r'%s.*?name="form.(\w+)(?:\.[\w\.]+)?"' % (error_msg,),
-                       re.DOTALL)
-    # compile it first because Python 2.3 doesn't allow flags in findall
-    return field in regex.findall(source)
-
-def missingInputErrorExists(field, source):
-    return validationErrorExists(field, 'Required input is missing.', source)
