@@ -69,7 +69,7 @@ class CheckBoxWidgetTest(SimpleInputWidgetTest):
 
     Default widget rendering:
 
-        >>> print normalize( widget() )
+        >>> print(normalize( widget() ))
         <input
           class="hiddenType"
           id="field.foo.used"
@@ -88,7 +88,7 @@ class CheckBoxWidgetTest(SimpleInputWidgetTest):
 
     Hidden rendering:
 
-        >>> print normalize( widget.hidden() )
+        >>> print(normalize( widget.hidden() ))
         <input
           class="hiddenType"
           id="field.foo"
@@ -100,7 +100,7 @@ class CheckBoxWidgetTest(SimpleInputWidgetTest):
     Calling setRenderedValue will change what gets output:
 
         >>> widget.setRenderedValue(False)
-        >>> print normalize( widget() )
+        >>> print(normalize( widget() ))
         <input
           class="hiddenType"
           id="field.foo.used"
@@ -157,22 +157,19 @@ class CheckBoxWidgetTest(SimpleInputWidgetTest):
         self.assertEqual(self._widget.getInputValue(), False)
         del self._widget.request.form['field.foo']
         self._widget.request.form['field.foo.used'] = ''
-        self.assertEquals(self._widget.getInputValue(), False)
+        self.assertEqual(self._widget.getInputValue(), False)
         del self._widget.request.form['field.foo.used']
         self.assertRaises(MissingInputError, self._widget.getInputValue)
 
     def test_required(self):
         # checkbox widgets are never required, since there's no way to
-        # set it to "no value"
-        self.failIf(self._widget.required)
-        self.assert_(self._widget.context.required)
+        # set it to "no value" even though the field is required by default
+        self.assertFalse(self._widget.required)
+        self.assertTrue(self._widget.context.required)
 
 
 def test_suite():
     return unittest.TestSuite((
         unittest.makeSuite(CheckBoxWidgetTest),
         doctest.DocTestSuite(),
-        ))
-
-if __name__=='__main__':
-    unittest.main(defaultTest='test_suite')
+    ))
