@@ -13,18 +13,16 @@
 ##############################################################################
 """File Widget tests
 """
-import unittest
-
 import doctest
-from StringIO import StringIO
+import unittest
+from zope.interface.verify import verifyClass
+
+from zope.formlib._compat import StringIO
 from zope.formlib.interfaces import IInputWidget
 from zope.formlib.widgets import FileWidget
-
 from zope.formlib.tests.test_browserwidget import (
     SimpleInputWidgetTest)
 
-from zope.interface.verify import verifyClass
-
 
 class FileWidgetTest(SimpleInputWidgetTest):
     """Documents and tests the file widget.
@@ -50,12 +48,12 @@ class FileWidgetTest(SimpleInputWidgetTest):
         self.assertEqual(self._widget.displayWidth, 20)
         self.assertEqual(self._widget.displayMaxWidth, '')
 
-    def test_hasInput(self): # override the usual one
+    def test_hasInput(self):  # override the usual one
         del self._widget.request.form['field.foo']
         self._widget.request.form['field.foo.used'] = ''
-        self.failUnless(self._widget.hasInput())
+        self.assertTrue(self._widget.hasInput())
         del self._widget.request.form['field.foo.used']
-        self.failIf(self._widget.hasInput())
+        self.assertFalse(self._widget.hasInput())
 
     def testRender(self):
         value = 'Foo Value'
@@ -75,7 +73,4 @@ def test_suite():
     return unittest.TestSuite((
         unittest.makeSuite(FileWidgetTest),
         doctest.DocTestSuite(),
-        ))
-
-if __name__=='__main__':
-    unittest.main(defaultTest='test_suite')
+    ))
