@@ -12,13 +12,11 @@
 #
 ##############################################################################
 """Decimal Widget Functional Tests
-
-$Id: test_functional_decimalwidget.py 112015 2010-05-05 18:27:23Z tseaver $
 """
 import unittest
 
 import decimal
-from zope.interface import Interface, implements
+from zope.interface import Interface, implementer
 from zope.schema import Decimal, Choice
 from zope.formlib import form
 from zope.publisher.browser import TestRequest
@@ -29,6 +27,7 @@ from zope.formlib.widgets import (
 from zope.formlib.tests.functionalsupport import FunctionalWidgetTestCase
 import zope.schema.interfaces
 
+
 class IDecimalTest(Interface):
 
     f1 = Decimal(
@@ -48,10 +47,9 @@ class IDecimalTest(Interface):
         missing_value=0)
 
 
+@implementer(IDecimalTest)
 class DecimalTest(object):
 
-    implements(IDecimalTest)
-
     def __init__(self):
         self.f1 = None
         self.f2 = decimal.Decimal("1.1")
@@ -61,29 +59,30 @@ class DecimalTest(object):
 class Form(form.EditForm):
     form_fields = form.fields(IDecimalTest)
 
+
 class Test(FunctionalWidgetTestCase):
     widgets = [
         (zope.schema.interfaces.IDecimal, DecimalWidget),
         (zope.schema.interfaces.IChoice, ChoiceInputWidget),
-        ((zope.schema.interfaces.IChoice, zope.schema.interfaces.IVocabularyTokenized),
-         DropdownWidget)]
+        ((zope.schema.interfaces.IChoice,
+          zope.schema.interfaces.IVocabularyTokenized), DropdownWidget)]
 
     def test_display_editform(self):
         foo = DecimalTest()
         request = TestRequest()
-        
+
         html = Form(foo, request)()
-        
+
         # f1 and f2 should be displayed in text fields
-        self.assert_(patternExists(
+        self.assertTrue(patternExists(
             '<input .* name="form.f1".* value="".*>', html))
-        self.assert_(patternExists(
+        self.assertTrue(patternExists(
             '<input .* name="form.f2".* value="1.1".*>', html))
 
         # f3 should be in a dropdown
-        self.assert_(patternExists(
+        self.assertTrue(patternExists(
             '<select .*name="form.f3".*>', html))
-        self.assert_(patternExists(
+        self.assertTrue(patternExists(
             '<option selected="selected" value="2.1">2.1</option>',
             html))
 
@@ -114,13 +113,14 @@ class Test(FunctionalWidgetTestCase):
 
         # check new values in object
         self.assertEqual(foo.f1, None)
-        self.assertEqual(foo.f2, None) # None is default missing_value
-        self.assertEqual(foo.f3, decimal.Decimal("1.1"))  # 0 is from f3.missing_value=0
+        self.assertEqual(foo.f2, None)  # None is default missing_value
+        # 0 is from f3.missing_value=0
+        self.assertEqual(foo.f3, decimal.Decimal("1.1"))
 
     def test_required_validation(self):
         foo = DecimalTest()
         request = TestRequest()
-        
+
         request.form['form.f1'] = ''
         request.form['form.f2'] = ''
         request.form['form.f3'] = ''
@@ -130,7 +130,7 @@ class Test(FunctionalWidgetTestCase):
         # confirm error msgs
         f3_index = html.find('form.f3')
         missing_index = html.find('Required input is missing')
-        self.assert_(missing_index > f3_index)
+        self.assertTrue(missing_index > f3_index)
 
     def test_invalid_allowed_value(self):
         foo = DecimalTest()
@@ -143,12 +143,12 @@ class Test(FunctionalWidgetTestCase):
 
         f3_index = html.find('form.f3')
         invalid_index = html.find('Invalid')
-        self.assert_(invalid_index > f3_index)
+        self.assertTrue(invalid_index > f3_index)
 
     def test_min_max_validation(self):
         foo = DecimalTest()
         request = TestRequest()
-        
+
         # submit value for f1 that is too low
         request.form['form.f1'] = '-1'
         request.form['form.actions.apply'] = u''
@@ -157,8 +157,8 @@ class Test(FunctionalWidgetTestCase):
         f1_index = html.find('form.f1')
         f2_index = html.find('form.f2')
         too_small_index = html.find('Value is too small')
-        self.assert_(too_small_index > f1_index)
-        self.assert_(html.find('Value is too small', f2_index) == -1)
+        self.assertTrue(too_small_index > f1_index)
+        self.assertTrue(html.find('Value is too small', f2_index) == -1)
 
         # submit value for f1 that is too high
         request.form['form.f1'] = '1000.2'
@@ -168,15 +168,15 @@ class Test(FunctionalWidgetTestCase):
         f1_index = html.find('form.f1')
         f2_index = html.find('form.f2')
         too_high_index = html.find('Value is too big')
-        self.assert_(too_high_index > f1_index)
-        self.assert_(html.find('Value is too small', f2_index) == -1)
+        self.assertTrue(too_high_index > f1_index)
+        self.assertTrue(html.find('Value is too small', f2_index) == -1)
 
     def test_omitted_value(self):
         foo = DecimalTest()
         request = TestRequest()
 
         # confirm default values
-        self.assert_(foo.f1 is None)
+        self.assertTrue(foo.f1 is None)
         self.assertEqual(foo.f2, decimal.Decimal("1.1"))
         self.assertEqual(foo.f3, decimal.Decimal("2.1"))
 
@@ -187,8 +187,8 @@ class Test(FunctionalWidgetTestCase):
         Form(foo, request)()
 
         # check new value in object
-        self.assert_(foo.f1 is None)
-        self.assert_(foo.f2 is None)
+        self.assertTrue(foo.f1 is None)
+        self.assertTrue(foo.f2 is None)
         self.assertEqual(foo.f3, decimal.Decimal("2.1"))
 
     def test_conversion(self):
@@ -203,12 +203,11 @@ class Test(FunctionalWidgetTestCase):
         f1_index = html.find('form.f1')
         f2_index = html.find('form.f2')
         invalid_index = html.find('Invalid decimal data')
-        self.assert_(invalid_index > f1_index)
-        self.assert_(html.find('Invalid decimal data', f2_index) == -1)
-        
+        self.assertTrue(invalid_index > f1_index)
+        self.assertTrue(html.find('Invalid decimal data', f2_index) == -1)
+
 
 def test_suite():
     suite = unittest.TestSuite()
     suite.addTest(unittest.makeSuite(Test))
     return suite
-
