@@ -12,12 +12,10 @@
 #
 ##############################################################################
 """Radio Widget Tests
-
-$Id: test_radiowidget.py 112015 2010-05-05 18:27:23Z tseaver $
 """
 import unittest
 import doctest
-from zope.interface import Interface, implements
+from zope.interface import Interface, implementer
 from zope.interface.verify import verifyClass
 from zope.publisher.browser import TestRequest
 from zope.schema import Choice
@@ -26,6 +24,7 @@ from zope.formlib.interfaces import IInputWidget
 from zope.formlib.widgets import RadioWidget
 from zope.formlib.tests.test_browserwidget import SimpleInputWidgetTest
 
+
 class RadioWidgetTest(SimpleInputWidgetTest):
     """Documents and tests the radio widget.
 
@@ -39,12 +38,14 @@ class RadioWidgetTest(SimpleInputWidgetTest):
     def setUpContent(self, desc=u'', title=u'Foo Title'):
         class ITestContent(Interface):
             foo = self._FieldFactory(
-                    title=title,
-                    description=desc,
-                    values=(u'foo', u'bar')
-                    )
+                title=title,
+                description=desc,
+                values=(u'foo', u'bar')
+            )
+
+        @implementer(ITestContent)
         class TestObject(object):
-            implements(ITestContent)
+            pass
 
         self.content = TestObject()
         field = ITestContent['foo']
@@ -58,7 +59,6 @@ class RadioWidgetTest(SimpleInputWidgetTest):
         self.assertEqual(self._widget.extra, '')
         self.assertEqual(self._widget.orientation, 'vertical')
 
-
     def testRenderItem(self):
         check_list = ('type="radio"', 'id="field.bar.0"',
                       'name="field.bar"', 'value="foo"', 'Foo')
@@ -71,7 +71,6 @@ class RadioWidgetTest(SimpleInputWidgetTest):
                 0, 'Foo', 'foo', 'field.bar', None),
             check_list)
 
-
     def testRenderItems(self):
         check_list = ('type="radio"', 'id="field.foo.0"', 'name="field.foo"',
                       'value="bar"', 'bar', 'value="foo"', 'foo',
@@ -79,7 +78,6 @@ class RadioWidgetTest(SimpleInputWidgetTest):
         self.verifyResult('\n'.join(self._widget.renderItems('bar')),
                           check_list)
 
-
     def testRender(self):
         value = 'bar'
         self._widget.setRenderedValue(value)
@@ -95,17 +93,15 @@ class RadioWidgetTest(SimpleInputWidgetTest):
         self._widget.extra = 'style="color: red"'
         self.verifyResult(self._widget.hidden(), check_list)
 
-
     def testHasInput(self):
         self._widget.request.form.clear()
-        self.assert_(not self._widget.hasInput())
+        self.assertTrue(not self._widget.hasInput())
         self._widget.request.form['field.foo-empty-marker'] = '1'
-        self.assert_(self._widget.hasInput())
+        self.assertTrue(self._widget.hasInput())
         self._widget.request.form['field.foo'] = u'Foo Value'
-        self.assert_(self._widget.hasInput())
+        self.assertTrue(self._widget.hasInput())
         del self._widget.request.form['field.foo-empty-marker']
-        self.assert_(self._widget.hasInput())
-
+        self.assertTrue(self._widget.hasInput())
 
     def testRenderEmptyMarker(self):
         self.verifyResult(self._widget(), ('field.foo-empty-marker',))
@@ -119,7 +115,4 @@ def test_suite():
     return unittest.TestSuite((
         unittest.makeSuite(RadioWidgetTest),
         doctest.DocTestSuite(),
-        ))
-
-if __name__=='__main__':
-    unittest.main(defaultTest='test_suite')
+    ))
