@@ -25,7 +25,6 @@ from zope.publisher.browser import BrowserView
 
 from zope.formlib.interfaces import ConversionError
 from zope.formlib.interfaces import WidgetInputError, MissingInputError
-from zope.formlib.interfaces import IInputWidget
 from zope.formlib.interfaces import IBrowserWidget
 from zope.formlib.interfaces import ISimpleInputWidget
 from zope.formlib.interfaces import IWidgetInputErrorView
@@ -41,7 +40,7 @@ if quoteattr("\r") != '"&13;"':
 
     def quoteattr(data):
         return _quoteattr(
-            data, {'\n': '&#10;', '\r': '&#13;', '\t':'&#9;'})
+            data, {'\n': '&#10;', '\r': '&#13;', '\t': '&#9;'})
 
 
 @implementer(IWidget)
@@ -132,6 +131,7 @@ class CustomWidgetFactory(object):
 
         return self._create(args)
 
+
 @implementer(IBrowserWidget)
 class BrowserWidget(Widget, BrowserView):
     """Base class for browser widgets.
@@ -372,7 +372,7 @@ class SimpleInputWidget(BrowserWidget, InputWidget):
 
 
     >>> tearDown()
-    """
+    """  # noqa: E501 line too long
 
     tag = u'input'
     type = u'text'
@@ -542,7 +542,6 @@ class DisplayWidget(BrowserWidget):
         super(DisplayWidget, self).__init__(context, request)
         self.required = False
 
-
     def __call__(self):
         if self._renderedValueSet():
             value = self._data
